document.addEventListener('DOMContentLoaded', function () {
    var scheduler = new bryntum.scheduler.Scheduler({
        // Element into which the Scheduler's DOM will be appended
        appendTo: 'scheduler-container',

        features: {
            group: false,

            // The TimeRanges store is taken care of by the CrudManager
            timeRanges: {
                showHeaderElements: true,
                enableResizing: true
            }
        },

        // Vertical spacing between stacked event bars when they overlap in time
        barMargin: 2,

        // The initial time range the Scheduler encompasses
        startDate: new Date(2017, 1, 7, 8),
        endDate: new Date(2017, 1, 7, 18),

        // Presets dictate the scale of the time units across
        // the top of the Scheduler
        viewPreset: 'hourAndDay',

        // Data fields from resources in frozen column set
        columns: [{
            text: 'Staff',
            field: 'name',
            width: 150
        }],

        // A CrudManager auto creates Resource and Event Stores
        // and takes care of loading and syncing data.
        crudManager: {
            autoLoad: true,
            autoSync: false,
            transport: {
                load: {
                    url: 'data.json'
                },
                sync: {
                    url: 'sync.php'
                }
            }
        }
    });

    var crudManager = scheduler.crudManager, 
        interceptStoreOps = {
            update : 1,
            add    : 1,
            remove : 1
        };

    crudManager.on('load', function() {
        crudManager.stores.forEach(function(store) {
            store.store.on('change', onStoreChange);
        });
    });

    var messagePopup;

    // Gather changes to display as formatted JSON
    function onStoreChange({source : store, action}) {
        var pack = crudManager.getChangeSetPackage(),
            message = [];

        // We log update, add, delete
        if (!interceptStoreOps[action]) {
            return;
        }

        // Tell the store everything is synced
        store.constructor.prototype.commit.call(store);

        if (pack.timeRanges) {
            if (pack.timeRanges.updated) {
                message.push('TimeRange change data:\r' + JSON.stringify(pack.timeRanges.updated, null, 4));
            }
        }
        if (pack.events) {
            if (pack.events.added) {
                message.push('Event add data:\r' + JSON.stringify(pack.events.added, null, 4));
            }
            if (pack.events.updated) {
                message.push('Event change data:\r' + JSON.stringify(pack.events.updated, null, 4));
            }
            if (pack.events.removed) {
                message.push('Event remove data:\r' + JSON.stringify(pack.events.removed, null, 4));
            }
        }
        if (pack.resources) {
            if (pack.resources.updated) {
                message.push('Resource change data:\r' + JSON.stringify(pack.resources.updated, null, 4));
            }
            if (pack.resources.removed) {
                message.push('Resource change data:\r' + JSON.stringify(pack.resources.removed, null, 4));
            }
        }

        if (!messagePopup) {
            messagePopup = new bryntum.scheduler.Popup({
                header: {
                    title: 'Changes to sync'
                },
                centered: true
            });
            // Stop hide on tap
            messagePopup.element.addEventListener('mousedown', function () {
                clearTimeout(messagePopup.hideTimer);
            });
        }
        messagePopup.html = '<pre><code>' + message.join('\r') + '</code></pre>';
        messagePopup.show();
        messagePopup.hideTimer = setTimeout(function () {
            messagePopup.hide();
        }, 5000);
    }

    // Show a simple toast message when clicking About
    document.getElementById('about').addEventListener('click', function (ev) {
        bryntum.scheduler.Toast.show('A simple demo page with the Bryntum Scheduler');
    });

    // Add a task when clicking 'Add task' button
    document.getElementById('addTask').addEventListener('click', function (ev) {
        var event = new scheduler.eventStore.modelClass({
            resourceId: scheduler.resourceStore.first.id,
            startDate: scheduler.startDate,
            duration: 1,
            durationUnit: 'h',
            name: 'New task'
        });

        scheduler.features.eventEdit.editEvent(event);
    });
});
